=======================
fast-templates
=======================

CLI that contains fastapi templates for different projects

Installation
============

This package is designed to be used with (`venv <https://docs.python.org/3/library/venv.html>`_), so make sure you have a virtual environment set up.

Use the package manager `pip <https://pip.pypa.io/en/stable/>`_ to install Fast-Templates.

.. code-block:: bash

   pip install fast-templates

Usage
=====

Once installed, and after activating your virtual environment, you can run the following command to see the available templates:

.. code-block:: bash

   fastcli

License
=======

`Mozilla Public License Version 2.0 <https://www.mozilla.org/en-US/MPL/2.0/>`_